var layerLoadErrorMessages=[];showMessage('Loading',staticTemplates.loadingModal[mode]);
function runGeeViz(){
try{
	Map2.addSerializedLayer({"result": "0", "values": {"1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": ["tStart", "tEnd", "tBreak", "changeProb", "red.*", "nir.*", "swir1.*", "swir2.*", "NDVI.*", "NBR.*"]}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "0": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "1"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}}},{"opacity": 0},'Raw CCDC Output',false);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Raw CCDC Output<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"2": {"constantValue": "tBreak"}, "5": {"constantValue": "changeProb"}, "6": {"constantValue": "NDVI.*"}, "4": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"constantValue": "tStart"}, {"constantValue": "tEnd"}, {"valueReference": "2"}, {"valueReference": "5"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"valueReference": "6"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "3": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "4"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "2"}]}}, "input": {"valueReference": "3"}}}}, "8": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "6"}]}}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_magnitude"]}, "input": {"valueReference": "3"}}}}}}}, "keys": {"valueReference": "1"}}}}, "9": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "7": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"valueReference": "8"}, "image2": {"valueReference": "9"}}}}, "10": {"constantValue": [1]}, "11": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "0": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["loss_year"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"valueReference": "1"}}}}, "mask": {"valueReference": "7"}}}}, "lengths": {"valueReference": "10"}}}}, "start": {"valueReference": "11"}}}}}}}, "mask": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["loss_mag"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"valueReference": "8"}, "mask": {"valueReference": "7"}}}}, "lengths": {"valueReference": "10"}}}}, "start": {"valueReference": "11"}}}}}}}, "image2": {"valueReference": "9"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["loss_mask"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "5"}]}}, "input": {"valueReference": "3"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}}}}, "keys": {"valueReference": "1"}}}}, "mask": {"valueReference": "7"}}}}, "lengths": {"valueReference": "10"}}}}, "start": {"valueReference": "11"}}}}}}}}}}}}}}},{"min": 1984, "max": 2021, "palette": "ffffe5,fff7bc,fee391,fec44f,fe9929,ec7014,cc4c02"},'Loss Year',true);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Loss Year<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"3": {"constantValue": "NDVI.*"}, "6": {"constantValue": "tBreak"}, "7": {"constantValue": "changeProb"}, "5": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"constantValue": "tStart"}, {"constantValue": "tEnd"}, {"valueReference": "6"}, {"valueReference": "7"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"valueReference": "3"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "4": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "5"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "8": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "6"}]}}, "input": {"valueReference": "4"}}}}, "2": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "3"}]}}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_magnitude"]}, "input": {"valueReference": "4"}}}}}}}, "keys": {"valueReference": "8"}}}}, "10": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "9": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"valueReference": "2"}, "image2": {"valueReference": "10"}}}}, "11": {"constantValue": [1]}, "12": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "1": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["loss_mag"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"valueReference": "2"}, "mask": {"valueReference": "9"}}}}, "lengths": {"valueReference": "11"}}}}, "start": {"valueReference": "12"}}}}}}}, "0": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"valueReference": "1"}, "mask": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"valueReference": "1"}, "image2": {"valueReference": "10"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["loss_mask"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "7"}]}}, "input": {"valueReference": "4"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}}}}, "keys": {"valueReference": "8"}}}}, "mask": {"valueReference": "9"}}}}, "lengths": {"valueReference": "11"}}}}, "start": {"valueReference": "12"}}}}}}}}}}}}}}},{"min": -0.5, "max": -0.1, "palette": ["D00", "F5DEB3"]},'Loss Mag',false);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Loss Mag<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"2": {"constantValue": "tBreak"}, "5": {"constantValue": "changeProb"}, "6": {"constantValue": "NDVI.*"}, "4": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"constantValue": "tStart"}, {"constantValue": "tEnd"}, {"valueReference": "2"}, {"valueReference": "5"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"valueReference": "6"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "3": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "4"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "2"}]}}, "input": {"valueReference": "3"}}}}, "8": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "6"}]}}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_magnitude"]}, "input": {"valueReference": "3"}}}}}}}, "keys": {"valueReference": "1"}}}}, "9": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "7": {"functionInvocationValue": {"functionName": "Image.gt", "arguments": {"image1": {"valueReference": "8"}, "image2": {"valueReference": "9"}}}}, "10": {"constantValue": [1]}, "11": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "0": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["gain_year"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"valueReference": "1"}}}}, "mask": {"valueReference": "7"}}}}, "lengths": {"valueReference": "10"}}}}, "start": {"valueReference": "11"}}}}}}}, "mask": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.gt", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["gain_mag"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"valueReference": "8"}, "mask": {"valueReference": "7"}}}}, "lengths": {"valueReference": "10"}}}}, "start": {"valueReference": "11"}}}}}}}, "image2": {"valueReference": "9"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["gain_mask"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "5"}]}}, "input": {"valueReference": "3"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}}}}, "keys": {"valueReference": "1"}}}}, "mask": {"valueReference": "7"}}}}, "lengths": {"valueReference": "10"}}}}, "start": {"valueReference": "11"}}}}}}}}}}}}}}},{"min": 1984, "max": 2021, "palette": "c5ee93,00a398"},'Gain Year',true);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Gain Year<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"3": {"constantValue": "NDVI.*"}, "6": {"constantValue": "tBreak"}, "7": {"constantValue": "changeProb"}, "5": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"constantValue": "tStart"}, {"constantValue": "tEnd"}, {"valueReference": "6"}, {"valueReference": "7"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"valueReference": "3"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "4": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "5"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "8": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "6"}]}}, "input": {"valueReference": "4"}}}}, "2": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "3"}]}}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_magnitude"]}, "input": {"valueReference": "4"}}}}}}}, "keys": {"valueReference": "8"}}}}, "10": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "9": {"functionInvocationValue": {"functionName": "Image.gt", "arguments": {"image1": {"valueReference": "2"}, "image2": {"valueReference": "10"}}}}, "11": {"constantValue": [1]}, "12": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "1": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["gain_mag"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"valueReference": "2"}, "mask": {"valueReference": "9"}}}}, "lengths": {"valueReference": "11"}}}}, "start": {"valueReference": "12"}}}}}}}, "0": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"valueReference": "1"}, "mask": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.gt", "arguments": {"image1": {"valueReference": "1"}, "image2": {"valueReference": "10"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"constantValue": [["gain_mask"]]}, "image": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayPad", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.arraySort", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "7"}]}}, "input": {"valueReference": "4"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}}}}, "keys": {"valueReference": "8"}}}}, "mask": {"valueReference": "9"}}}}, "lengths": {"valueReference": "11"}}}}, "start": {"valueReference": "12"}}}}}}}}}}}}}}},{"min": 0.05, "max": 0.2, "palette": "F5DEB3,006400"},'Gain Mag',false);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Gain Mag<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_fitted"]}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "4": {"constantValue": "NBR"}, "5": {"constantValue": "_.*"}, "3": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "4"}, "string2": {"valueReference": "5"}}}}]}}, "6": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_INTP"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "11": {"constantValue": "year"}, "12": {"functionInvocationValue": {"functionName": "Number.int16", "arguments": {"input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "10": {"functionInvocationValue": {"functionName": "Element.set", "arguments": {"key": {"constantValue": "system:time_start"}, "object": {"functionInvocationValue": {"functionName": "Image.rename", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.float", "arguments": {"value": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "names": {"arrayValue": {"values": [{"valueReference": "11"}]}}}}}, "value": {"functionInvocationValue": {"functionName": "Date.millis", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.advance", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.fromYMD", "arguments": {"day": {"constantValue": 31}, "month": {"constantValue": 12}, "year": {"functionInvocationValue": {"functionName": "Number.subtract", "arguments": {"left": {"valueReference": "12"}, "right": {"constantValue": 1}}}}}}}, "delta": {"functionInvocationValue": {"functionName": "Number.subtract", "arguments": {"left": {"argumentReference": "_MAPPING_VAR_0_0"}, "right": {"valueReference": "12"}}}}, "unit": {"valueReference": "11"}}}}}}}}}}, "13": {"functionInvocationValue": {"functionName": "Number.divide", "arguments": {"left": {"functionInvocationValue": {"functionName": "Number.parse", "arguments": {"input": {"functionInvocationValue": {"functionName": "Date.format", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.fromYMD", "arguments": {"day": {"constantValue": 1}, "month": {"constantValue": 1}, "year": {"constantValue": 1984}}}}, "format": {"constantValue": "DDD"}}}}}}}, "right": {"constantValue": 365}}}}, "9": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "ImageCollection.fromImages", "arguments": {"images": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "10"}}, "list": {"functionInvocationValue": {"functionName": "List.sequence", "arguments": {"end": {"functionInvocationValue": {"functionName": "Number.add", "arguments": {"left": {"constantValue": 2021}, "right": {"valueReference": "13"}}}}, "start": {"functionInvocationValue": {"functionName": "Number.add", "arguments": {"left": {"constantValue": 1984}, "right": {"valueReference": "13"}}}}, "step": {"constantValue": 0.1}}}}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 2021}, "field": {"valueReference": "11"}, "start": {"constantValue": 1984}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 365}, "start": {"constantValue": 1}}}}}}}, "8": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "List.get", "arguments": {"index": {"constantValue": 0}, "list": {"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [0]}, "input": {"functionInvocationValue": {"functionName": "Collection.first", "arguments": {"collection": {"valueReference": "9"}}}}}}}}}}}}}]}}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "7": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_SLP"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "image2": {"valueReference": "8"}}}}, "16": {"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"constantValue": ".*"}, "string2": {"functionInvocationValue": {"functionName": "Number.format", "arguments": {"number": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "15": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "16"}}, "list": {"constantValue": [1, 2, 3]}}}}, "14": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "15"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_SIN.*"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}}}}, "19": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}, "18": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"valueReference": "19"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 2}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 3}}}}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"functionInvocationValue": {"functionName": "Number.multiply", "arguments": {"left": {"constantValue": 2.0}, "right": {"constantValue": 3.141592653589793}}}}}}}}}}, "image2": {"valueReference": "8"}}}}, "17": {"functionInvocationValue": {"functionName": "Image.sin", "arguments": {"value": {"valueReference": "18"}}}}, "20": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "15"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_COS.*"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}}}}, "21": {"functionInvocationValue": {"functionName": "Image.cos", "arguments": {"value": {"valueReference": "18"}}}}, "22": {"functionInvocationValue": {"functionName": "Reducer.sum", "arguments": {}}}, "24": {"constantValue": "NDVI"}, "23": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "24"}, "string2": {"valueReference": "5"}}}}]}}, "26": {"constantValue": "nir"}, "25": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "26"}, "string2": {"valueReference": "5"}}}}]}}, "28": {"constantValue": "red"}, "27": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "28"}, "string2": {"valueReference": "5"}}}}]}}, "30": {"constantValue": "swir1"}, "29": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "30"}, "string2": {"valueReference": "5"}}}}]}}, "32": {"constantValue": "swir2"}, "31": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "32"}, "string2": {"valueReference": "5"}}}}]}}, "33": {"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"argumentReference": "_MAPPING_VAR_0_0"}, "string2": {"constantValue": "_CCDC_fitted"}}}}, "2": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"argumentReference": "_MAPPING_VAR_3_0"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.rename", "arguments": {"input": {"functionInvocationValue": {"functionName": "ImageCollection.toBands", "arguments": {"collection": {"functionInvocationValue": {"functionName": "ImageCollection.fromImages", "arguments": {"images": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}]}}}}}}}}, "names": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "33"}}, "list": {"arrayValue": {"values": [{"valueReference": "4"}, {"valueReference": "24"}, {"valueReference": "26"}, {"valueReference": "28"}, {"valueReference": "30"}, {"valueReference": "32"}]}}}}}}}}}}}, "39": {"constantValue": "tStart"}, "40": {"constantValue": "tEnd"}, "41": {"constantValue": "tBreak"}, "38": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "39"}, {"valueReference": "40"}, {"valueReference": "41"}, {"constantValue": "changeProb"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"constantValue": "NDVI.*"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "37": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "38"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "36": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_coefs"]}, "input": {"valueReference": "37"}}}}, "42": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "39"}]}}, "input": {"valueReference": "37"}}}}, "43": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "45": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "44": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "end": {"valueReference": "45"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "41"}]}}, "input": {"valueReference": "37"}}}}, "start": {"valueReference": "43"}}}}, "46": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "40"}]}}, "input": {"valueReference": "37"}}}}, "35": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"valueReference": "36"}}}}, {"constantValue": ["INTP", "SLP", "COS1", "SIN1", "COS2", "SIN2", "COS3", "SIN3"]}]}}, "image": {"functionInvocationValue": {"functionName": "Image.arrayTranspose", "arguments": {"axis1": {"constantValue": 1}, "axis2": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayProject", "arguments": {"axes": {"constantValue": [2, 1]}, "input": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.toArray", "arguments": {"axis": {"constantValue": 2}, "image": {"valueReference": "36"}}}}, "mask": {"functionInvocationValue": {"functionName": "Image.arrayRepeat", "arguments": {"axis": {"constantValue": 2}, "copies": {"valueReference": "19"}, "input": {"functionInvocationValue": {"functionName": "Image.arrayRepeat", "arguments": {"axis": {"constantValue": 1}, "copies": {"valueReference": "19"}, "input": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"functionInvocationValue": {"functionName": "If", "arguments": {"condition": {"constantValue": false}, "falseCase": {"valueReference": "42"}, "trueCase": {"functionInvocationValue": {"functionName": "Image.arrayCat", "arguments": {"axis": {"constantValue": 0}, "image1": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "end": {"valueReference": "19"}, "input": {"valueReference": "42"}, "start": {"valueReference": "43"}}}}, "image2": {"valueReference": "44"}}}}}}}, "image2": {"argumentReference": "_MAPPING_VAR_1_0"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "If", "arguments": {"condition": {"constantValue": false}, "falseCase": {"valueReference": "46"}, "trueCase": {"functionInvocationValue": {"functionName": "Image.arrayCat", "arguments": {"axis": {"constantValue": 0}, "image1": {"valueReference": "44"}, "image2": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"valueReference": "46"}, "start": {"valueReference": "45"}}}}}}}}}}, "image2": {"argumentReference": "_MAPPING_VAR_1_0"}}}}}}}}}}}}}}}}}}}}}}}}}, "34": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"argumentReference": "_MAPPING_VAR_1_0"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"valueReference": "35"}, "mask": {"functionInvocationValue": {"functionName": "Image.neq", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"valueReference": "35"}, "reducer": {"functionInvocationValue": {"functionName": "Reducer.max", "arguments": {}}}}}}, "image2": {"valueReference": "43"}}}}}}}}}}, "0": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "1"}}, "collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_3_0"], "body": "2"}}, "collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_1_0"], "body": "34"}}, "collection": {"valueReference": "9"}}}}}}}}}}}},{"opacity": 0},'Fitted CCDC',true);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Fitted CCDC<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_fitted"]}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "4": {"constantValue": "NBR"}, "5": {"constantValue": "_.*"}, "3": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "4"}, "string2": {"valueReference": "5"}}}}]}}, "6": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_INTP"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "11": {"constantValue": "year"}, "12": {"functionInvocationValue": {"functionName": "Number.int16", "arguments": {"input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "10": {"functionInvocationValue": {"functionName": "Element.set", "arguments": {"key": {"constantValue": "system:time_start"}, "object": {"functionInvocationValue": {"functionName": "Image.rename", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.float", "arguments": {"value": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "names": {"arrayValue": {"values": [{"valueReference": "11"}]}}}}}, "value": {"functionInvocationValue": {"functionName": "Date.millis", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.advance", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.fromYMD", "arguments": {"day": {"constantValue": 31}, "month": {"constantValue": 12}, "year": {"functionInvocationValue": {"functionName": "Number.subtract", "arguments": {"left": {"valueReference": "12"}, "right": {"constantValue": 1}}}}}}}, "delta": {"functionInvocationValue": {"functionName": "Number.subtract", "arguments": {"left": {"argumentReference": "_MAPPING_VAR_0_0"}, "right": {"valueReference": "12"}}}}, "unit": {"valueReference": "11"}}}}}}}}}}, "13": {"functionInvocationValue": {"functionName": "Number.divide", "arguments": {"left": {"functionInvocationValue": {"functionName": "Number.parse", "arguments": {"input": {"functionInvocationValue": {"functionName": "Date.format", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.fromYMD", "arguments": {"day": {"constantValue": 1}, "month": {"constantValue": 1}, "year": {"constantValue": 1984}}}}, "format": {"constantValue": "DDD"}}}}}}}, "right": {"constantValue": 365}}}}, "9": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "ImageCollection.fromImages", "arguments": {"images": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "10"}}, "list": {"functionInvocationValue": {"functionName": "List.sequence", "arguments": {"end": {"functionInvocationValue": {"functionName": "Number.add", "arguments": {"left": {"constantValue": 2021}, "right": {"valueReference": "13"}}}}, "start": {"functionInvocationValue": {"functionName": "Number.add", "arguments": {"left": {"constantValue": 1984}, "right": {"valueReference": "13"}}}}, "step": {"constantValue": 0.1}}}}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 2021}, "field": {"valueReference": "11"}, "start": {"constantValue": 1984}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 365}, "start": {"constantValue": 1}}}}}}}, "8": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "List.get", "arguments": {"index": {"constantValue": 0}, "list": {"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [0]}, "input": {"functionInvocationValue": {"functionName": "Collection.first", "arguments": {"collection": {"valueReference": "9"}}}}}}}}}}}}}]}}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "7": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_SLP"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "image2": {"valueReference": "8"}}}}, "16": {"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"constantValue": ".*"}, "string2": {"functionInvocationValue": {"functionName": "Number.format", "arguments": {"number": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "15": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "16"}}, "list": {"constantValue": [1, 2, 3]}}}}, "14": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "15"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_SIN.*"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}}}}, "19": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}, "18": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"valueReference": "19"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 2}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 3}}}}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"functionInvocationValue": {"functionName": "Number.multiply", "arguments": {"left": {"constantValue": 2.0}, "right": {"constantValue": 3.141592653589793}}}}}}}}}}, "image2": {"valueReference": "8"}}}}, "17": {"functionInvocationValue": {"functionName": "Image.sin", "arguments": {"value": {"valueReference": "18"}}}}, "20": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "15"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_COS.*"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}}}}, "21": {"functionInvocationValue": {"functionName": "Image.cos", "arguments": {"value": {"valueReference": "18"}}}}, "22": {"functionInvocationValue": {"functionName": "Reducer.sum", "arguments": {}}}, "24": {"constantValue": "NDVI"}, "23": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "24"}, "string2": {"valueReference": "5"}}}}]}}, "26": {"constantValue": "nir"}, "25": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "26"}, "string2": {"valueReference": "5"}}}}]}}, "28": {"constantValue": "red"}, "27": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "28"}, "string2": {"valueReference": "5"}}}}]}}, "30": {"constantValue": "swir1"}, "29": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "30"}, "string2": {"valueReference": "5"}}}}]}}, "32": {"constantValue": "swir2"}, "31": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "32"}, "string2": {"valueReference": "5"}}}}]}}, "33": {"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"argumentReference": "_MAPPING_VAR_0_0"}, "string2": {"constantValue": "_CCDC_fitted"}}}}, "2": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"argumentReference": "_MAPPING_VAR_3_0"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.rename", "arguments": {"input": {"functionInvocationValue": {"functionName": "ImageCollection.toBands", "arguments": {"collection": {"functionInvocationValue": {"functionName": "ImageCollection.fromImages", "arguments": {"images": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "3"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "23"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "25"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "27"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "29"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "6"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "7"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "14"}}}}, "image2": {"valueReference": "17"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "31"}, "input": {"valueReference": "20"}}}}, "image2": {"valueReference": "21"}}}}}}}, "reducer": {"valueReference": "22"}}}}]}}}}}}}}, "names": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "33"}}, "list": {"arrayValue": {"values": [{"valueReference": "4"}, {"valueReference": "24"}, {"valueReference": "26"}, {"valueReference": "28"}, {"valueReference": "30"}, {"valueReference": "32"}]}}}}}}}}}}}, "39": {"constantValue": "tStart"}, "40": {"constantValue": "tEnd"}, "41": {"constantValue": "tBreak"}, "38": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "39"}, {"valueReference": "40"}, {"valueReference": "41"}, {"constantValue": "changeProb"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"constantValue": "NDVI.*"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "37": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "38"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "36": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_coefs"]}, "input": {"valueReference": "37"}}}}, "42": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "39"}]}}, "input": {"valueReference": "37"}}}}, "43": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "45": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "44": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "end": {"valueReference": "45"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "41"}]}}, "input": {"valueReference": "37"}}}}, "start": {"valueReference": "43"}}}}, "46": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "40"}]}}, "input": {"valueReference": "37"}}}}, "35": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"valueReference": "36"}}}}, {"constantValue": ["INTP", "SLP", "COS1", "SIN1", "COS2", "SIN2", "COS3", "SIN3"]}]}}, "image": {"functionInvocationValue": {"functionName": "Image.arrayTranspose", "arguments": {"axis1": {"constantValue": 1}, "axis2": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayProject", "arguments": {"axes": {"constantValue": [2, 1]}, "input": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.toArray", "arguments": {"axis": {"constantValue": 2}, "image": {"valueReference": "36"}}}}, "mask": {"functionInvocationValue": {"functionName": "Image.arrayRepeat", "arguments": {"axis": {"constantValue": 2}, "copies": {"valueReference": "19"}, "input": {"functionInvocationValue": {"functionName": "Image.arrayRepeat", "arguments": {"axis": {"constantValue": 1}, "copies": {"valueReference": "19"}, "input": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"functionInvocationValue": {"functionName": "If", "arguments": {"condition": {"constantValue": false}, "falseCase": {"valueReference": "42"}, "trueCase": {"functionInvocationValue": {"functionName": "Image.arrayCat", "arguments": {"axis": {"constantValue": 0}, "image1": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "end": {"valueReference": "19"}, "input": {"valueReference": "42"}, "start": {"valueReference": "43"}}}}, "image2": {"valueReference": "44"}}}}}}}, "image2": {"argumentReference": "_MAPPING_VAR_1_0"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "If", "arguments": {"condition": {"constantValue": false}, "falseCase": {"valueReference": "46"}, "trueCase": {"functionInvocationValue": {"functionName": "Image.arrayCat", "arguments": {"axis": {"constantValue": 0}, "image1": {"valueReference": "44"}, "image2": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"valueReference": "46"}, "start": {"valueReference": "45"}}}}}}}}}}, "image2": {"argumentReference": "_MAPPING_VAR_1_0"}}}}}}}}}}}}}}}}}}}}}}}}}, "34": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"argumentReference": "_MAPPING_VAR_1_0"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"valueReference": "35"}, "mask": {"functionInvocationValue": {"functionName": "Image.neq", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"valueReference": "35"}, "reducer": {"functionInvocationValue": {"functionName": "Reducer.max", "arguments": {}}}}}}, "image2": {"valueReference": "43"}}}}}}}}}}, "0": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "1"}}, "collection": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_3_0"], "body": "2"}}, "collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_1_0"], "body": "34"}}, "collection": {"valueReference": "9"}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 1990}, "field": {"valueReference": "11"}, "start": {"constantValue": 1990}}}}}}}}}}}},{"opacity": 0},'Fitted CCDC 1990',true);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Fitted CCDC 1990<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"3": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_fitted"]}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "7": {"constantValue": "NBR"}, "8": {"constantValue": "_.*"}, "6": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "7"}, "string2": {"valueReference": "8"}}}}]}}, "9": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_INTP"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "14": {"constantValue": "year"}, "15": {"functionInvocationValue": {"functionName": "Number.int16", "arguments": {"input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "13": {"functionInvocationValue": {"functionName": "Element.set", "arguments": {"key": {"constantValue": "system:time_start"}, "object": {"functionInvocationValue": {"functionName": "Image.rename", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.float", "arguments": {"value": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "names": {"arrayValue": {"values": [{"valueReference": "14"}]}}}}}, "value": {"functionInvocationValue": {"functionName": "Date.millis", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.advance", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.fromYMD", "arguments": {"day": {"constantValue": 31}, "month": {"constantValue": 12}, "year": {"functionInvocationValue": {"functionName": "Number.subtract", "arguments": {"left": {"valueReference": "15"}, "right": {"constantValue": 1}}}}}}}, "delta": {"functionInvocationValue": {"functionName": "Number.subtract", "arguments": {"left": {"argumentReference": "_MAPPING_VAR_0_0"}, "right": {"valueReference": "15"}}}}, "unit": {"valueReference": "14"}}}}}}}}}}, "16": {"functionInvocationValue": {"functionName": "Number.divide", "arguments": {"left": {"functionInvocationValue": {"functionName": "Number.parse", "arguments": {"input": {"functionInvocationValue": {"functionName": "Date.format", "arguments": {"date": {"functionInvocationValue": {"functionName": "Date.fromYMD", "arguments": {"day": {"constantValue": 1}, "month": {"constantValue": 1}, "year": {"constantValue": 1984}}}}, "format": {"constantValue": "DDD"}}}}}}}, "right": {"constantValue": 365}}}}, "12": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "ImageCollection.fromImages", "arguments": {"images": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "13"}}, "list": {"functionInvocationValue": {"functionName": "List.sequence", "arguments": {"end": {"functionInvocationValue": {"functionName": "Number.add", "arguments": {"left": {"constantValue": 2021}, "right": {"valueReference": "16"}}}}, "start": {"functionInvocationValue": {"functionName": "Number.add", "arguments": {"left": {"constantValue": 1984}, "right": {"valueReference": "16"}}}}, "step": {"constantValue": 0.1}}}}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 2021}, "field": {"valueReference": "14"}, "start": {"constantValue": 1984}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 365}, "start": {"constantValue": 1}}}}}}}, "11": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "List.get", "arguments": {"index": {"constantValue": 0}, "list": {"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [0]}, "input": {"functionInvocationValue": {"functionName": "Collection.first", "arguments": {"collection": {"valueReference": "12"}}}}}}}}}}}}}]}}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "10": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_SLP"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}, "image2": {"valueReference": "11"}}}}, "19": {"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"constantValue": ".*"}, "string2": {"functionInvocationValue": {"functionName": "Number.format", "arguments": {"number": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "18": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "19"}}, "list": {"constantValue": [1, 2, 3]}}}}, "17": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "18"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_SIN.*"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}}}}, "22": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 1}}}}, "21": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"valueReference": "22"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 2}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 3}}}}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"functionInvocationValue": {"functionName": "Number.multiply", "arguments": {"left": {"constantValue": 2.0}, "right": {"constantValue": 3.141592653589793}}}}}}}}}}, "image2": {"valueReference": "11"}}}}, "20": {"functionInvocationValue": {"functionName": "Image.sin", "arguments": {"value": {"valueReference": "21"}}}}, "23": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "18"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_COS.*"]}, "input": {"argumentReference": "_MAPPING_VAR_3_0"}}}}}}}, "24": {"functionInvocationValue": {"functionName": "Image.cos", "arguments": {"value": {"valueReference": "21"}}}}, "25": {"functionInvocationValue": {"functionName": "Reducer.sum", "arguments": {}}}, "27": {"constantValue": "NDVI"}, "26": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "27"}, "string2": {"valueReference": "8"}}}}]}}, "29": {"constantValue": "nir"}, "28": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "29"}, "string2": {"valueReference": "8"}}}}]}}, "31": {"constantValue": "red"}, "30": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "31"}, "string2": {"valueReference": "8"}}}}]}}, "33": {"constantValue": "swir1"}, "32": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "33"}, "string2": {"valueReference": "8"}}}}]}}, "35": {"constantValue": "swir2"}, "34": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"valueReference": "35"}, "string2": {"valueReference": "8"}}}}]}}, "36": {"functionInvocationValue": {"functionName": "String.cat", "arguments": {"string1": {"argumentReference": "_MAPPING_VAR_0_0"}, "string2": {"constantValue": "_CCDC_fitted"}}}}, "5": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"argumentReference": "_MAPPING_VAR_3_0"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.rename", "arguments": {"input": {"functionInvocationValue": {"functionName": "ImageCollection.toBands", "arguments": {"collection": {"functionInvocationValue": {"functionName": "ImageCollection.fromImages", "arguments": {"images": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "6"}, "input": {"valueReference": "9"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "6"}, "input": {"valueReference": "10"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "6"}, "input": {"valueReference": "17"}}}}, "image2": {"valueReference": "20"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "6"}, "input": {"valueReference": "23"}}}}, "image2": {"valueReference": "24"}}}}}}}, "reducer": {"valueReference": "25"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "26"}, "input": {"valueReference": "9"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "26"}, "input": {"valueReference": "10"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "26"}, "input": {"valueReference": "17"}}}}, "image2": {"valueReference": "20"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "26"}, "input": {"valueReference": "23"}}}}, "image2": {"valueReference": "24"}}}}}}}, "reducer": {"valueReference": "25"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "28"}, "input": {"valueReference": "9"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "28"}, "input": {"valueReference": "10"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "28"}, "input": {"valueReference": "17"}}}}, "image2": {"valueReference": "20"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "28"}, "input": {"valueReference": "23"}}}}, "image2": {"valueReference": "24"}}}}}}}, "reducer": {"valueReference": "25"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "30"}, "input": {"valueReference": "9"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "30"}, "input": {"valueReference": "10"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "30"}, "input": {"valueReference": "17"}}}}, "image2": {"valueReference": "20"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "30"}, "input": {"valueReference": "23"}}}}, "image2": {"valueReference": "24"}}}}}}}, "reducer": {"valueReference": "25"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "32"}, "input": {"valueReference": "9"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "32"}, "input": {"valueReference": "10"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "32"}, "input": {"valueReference": "17"}}}}, "image2": {"valueReference": "20"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "32"}, "input": {"valueReference": "23"}}}}, "image2": {"valueReference": "24"}}}}}}}, "reducer": {"valueReference": "25"}}}}, {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "34"}, "input": {"valueReference": "9"}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "34"}, "input": {"valueReference": "10"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "34"}, "input": {"valueReference": "17"}}}}, "image2": {"valueReference": "20"}}}}}}}, "srcImg": {"functionInvocationValue": {"functionName": "Image.multiply", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "34"}, "input": {"valueReference": "23"}}}}, "image2": {"valueReference": "24"}}}}}}}, "reducer": {"valueReference": "25"}}}}]}}}}}}}}, "names": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "36"}}, "list": {"arrayValue": {"values": [{"valueReference": "7"}, {"valueReference": "27"}, {"valueReference": "29"}, {"valueReference": "31"}, {"valueReference": "33"}, {"valueReference": "35"}]}}}}}}}}}}}, "42": {"constantValue": "tStart"}, "43": {"constantValue": "tEnd"}, "44": {"constantValue": "tBreak"}, "41": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "42"}, {"valueReference": "43"}, {"valueReference": "44"}, {"constantValue": "changeProb"}, {"constantValue": "red.*"}, {"constantValue": "nir.*"}, {"constantValue": "swir1.*"}, {"constantValue": "swir2.*"}, {"constantValue": "NDVI.*"}, {"constantValue": "NBR.*"}]}}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "40": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "41"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}, "39": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": [".*_coefs"]}, "input": {"valueReference": "40"}}}}, "45": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "42"}]}}, "input": {"valueReference": "40"}}}}, "46": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": 0}}}}, "48": {"functionInvocationValue": {"functionName": "Image.constant", "arguments": {"value": {"constantValue": -1}}}}, "47": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "end": {"valueReference": "48"}, "input": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "44"}]}}, "input": {"valueReference": "40"}}}}, "start": {"valueReference": "46"}}}}, "49": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"arrayValue": {"values": [{"valueReference": "43"}]}}, "input": {"valueReference": "40"}}}}, "38": {"functionInvocationValue": {"functionName": "Image.arrayFlatten", "arguments": {"coordinateLabels": {"arrayValue": {"values": [{"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"valueReference": "39"}}}}, {"constantValue": ["INTP", "SLP", "COS1", "SIN1", "COS2", "SIN2", "COS3", "SIN3"]}]}}, "image": {"functionInvocationValue": {"functionName": "Image.arrayTranspose", "arguments": {"axis1": {"constantValue": 1}, "axis2": {"constantValue": 0}, "input": {"functionInvocationValue": {"functionName": "Image.arrayProject", "arguments": {"axes": {"constantValue": [2, 1]}, "input": {"functionInvocationValue": {"functionName": "Image.arrayMask", "arguments": {"input": {"functionInvocationValue": {"functionName": "Image.toArray", "arguments": {"axis": {"constantValue": 2}, "image": {"valueReference": "39"}}}}, "mask": {"functionInvocationValue": {"functionName": "Image.arrayRepeat", "arguments": {"axis": {"constantValue": 2}, "copies": {"valueReference": "22"}, "input": {"functionInvocationValue": {"functionName": "Image.arrayRepeat", "arguments": {"axis": {"constantValue": 1}, "copies": {"valueReference": "22"}, "input": {"functionInvocationValue": {"functionName": "Image.and", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.lt", "arguments": {"image1": {"functionInvocationValue": {"functionName": "If", "arguments": {"condition": {"constantValue": false}, "falseCase": {"valueReference": "45"}, "trueCase": {"functionInvocationValue": {"functionName": "Image.arrayCat", "arguments": {"axis": {"constantValue": 0}, "image1": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "end": {"valueReference": "22"}, "input": {"valueReference": "45"}, "start": {"valueReference": "46"}}}}, "image2": {"valueReference": "47"}}}}}}}, "image2": {"argumentReference": "_MAPPING_VAR_1_0"}}}}, "image2": {"functionInvocationValue": {"functionName": "Image.gte", "arguments": {"image1": {"functionInvocationValue": {"functionName": "If", "arguments": {"condition": {"constantValue": false}, "falseCase": {"valueReference": "49"}, "trueCase": {"functionInvocationValue": {"functionName": "Image.arrayCat", "arguments": {"axis": {"constantValue": 0}, "image1": {"valueReference": "47"}, "image2": {"functionInvocationValue": {"functionName": "Image.arraySlice", "arguments": {"axis": {"constantValue": 0}, "input": {"valueReference": "49"}, "start": {"valueReference": "48"}}}}}}}}}}, "image2": {"argumentReference": "_MAPPING_VAR_1_0"}}}}}}}}}}}}}}}}}}}}}}}}}, "37": {"functionInvocationValue": {"functionName": "Image.addBands", "arguments": {"dstImg": {"argumentReference": "_MAPPING_VAR_1_0"}, "srcImg": {"functionInvocationValue": {"functionName": "Image.updateMask", "arguments": {"image": {"valueReference": "38"}, "mask": {"functionInvocationValue": {"functionName": "Image.neq", "arguments": {"image1": {"functionInvocationValue": {"functionName": "Image.reduce", "arguments": {"image": {"valueReference": "38"}, "reducer": {"functionInvocationValue": {"functionName": "Reducer.max", "arguments": {}}}}}}, "image2": {"valueReference": "46"}}}}}}}}}}, "4": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_3_0"], "body": "5"}}, "collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_1_0"], "body": "37"}}, "collection": {"valueReference": "12"}}}}}}}, "2": {"functionInvocationValue": {"functionName": "Image.bandNames", "arguments": {"image": {"functionInvocationValue": {"functionName": "Collection.first", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "3"}}, "collection": {"valueReference": "4"}}}}}}}}}}, "50": {"functionInvocationValue": {"functionName": "List.get", "arguments": {"index": {"constantValue": 0}, "list": {"functionInvocationValue": {"functionName": "String.split", "arguments": {"regex": {"constantValue": "_"}, "string": {"argumentReference": "_MAPPING_VAR_0_0"}}}}}}}, "1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"valueReference": "2"}, "input": {"argumentReference": "_MAPPING_VAR_8_0"}, "newNames": {"functionInvocationValue": {"functionName": "List.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "50"}}, "list": {"valueReference": "2"}}}}}}}, "0": {"functionInvocationValue": {"functionName": "Collection.first", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.filter", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_8_0"], "body": "1"}}, "collection": {"valueReference": "4"}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 2020}, "field": {"valueReference": "14"}, "start": {"constantValue": 2020}}}}}}}, "filter": {"functionInvocationValue": {"functionName": "Filter.calendarRange", "arguments": {"end": {"constantValue": 250}, "start": {"constantValue": 190}}}}}}}}}}}},{"min": 0.05, "max": [0.5, 0.6, 0.6], "bands": "swir1,nir,red", "gamma": 1.6},'Synthetic Composite',true);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Synthetic Composite<br>GEE "+err);}
try{
	Map2.addSerializedLayer({"result": "0", "values": {"1": {"functionInvocationValue": {"functionName": "Image.select", "arguments": {"bandSelectors": {"constantValue": ["tStart", "tEnd", "tBreak", "changeProb", "red.*", "nir.*", "swir1.*", "swir2.*", "NDVI.*", "NBR.*"]}, "input": {"argumentReference": "_MAPPING_VAR_0_0"}}}}, "0": {"functionInvocationValue": {"functionName": "Image.geometry", "arguments": {"feature": {"functionInvocationValue": {"functionName": "ImageCollection.mosaic", "arguments": {"collection": {"functionInvocationValue": {"functionName": "Collection.map", "arguments": {"baseAlgorithm": {"functionDefinitionValue": {"argumentNames": ["_MAPPING_VAR_0_0"], "body": "1"}}, "collection": {"functionInvocationValue": {"functionName": "ImageCollection.load", "arguments": {"id": {"constantValue": "projects/lcms-292214/assets/CONUS-LCMS/Base-Learners/CCDC-Collection-1984-2022"}}}}}}}}}}}}}}},{"strokeColor": "0000FF"},'Study Area',false);
}catch(err){
	layerLoadErrorMessages.push("Error loading: Study Area<br>GEE "+err);}
if(layerLoadErrorMessages.length>0){showMessage("Map.addLayer Error List",layerLoadErrorMessages.join("<br>"));}
setTimeout(function(){if(layerLoadErrorMessages.length===0){$('#close-modal-button').click();}}, 2500);
$('#query-label').click();
queryWindowMode = "sidePane"
}